# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ZoneImportArgs', 'ZoneImport']

@pulumi.input_type
class ZoneImportArgs:
    def __init__(__self__, *,
                 zone_file: pulumi.Input[builtins.str],
                 zone_name: pulumi.Input[builtins.str]):
        """
        The set of arguments for constructing a ZoneImport resource.
        :param pulumi.Input[builtins.str] zone_file: Content of the zone file to import
        :param pulumi.Input[builtins.str] zone_name: The name of the domain zone
        """
        pulumi.set(__self__, "zone_file", zone_file)
        pulumi.set(__self__, "zone_name", zone_name)

    @property
    @pulumi.getter(name="zoneFile")
    def zone_file(self) -> pulumi.Input[builtins.str]:
        """
        Content of the zone file to import
        """
        return pulumi.get(self, "zone_file")

    @zone_file.setter
    def zone_file(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "zone_file", value)

    @property
    @pulumi.getter(name="zoneName")
    def zone_name(self) -> pulumi.Input[builtins.str]:
        """
        The name of the domain zone
        """
        return pulumi.get(self, "zone_name")

    @zone_name.setter
    def zone_name(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "zone_name", value)


@pulumi.input_type
class _ZoneImportState:
    def __init__(__self__, *,
                 exported_content: Optional[pulumi.Input[builtins.str]] = None,
                 zone_file: Optional[pulumi.Input[builtins.str]] = None,
                 zone_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering ZoneImport resources.
        :param pulumi.Input[builtins.str] exported_content: Zone file exported from the API
        :param pulumi.Input[builtins.str] zone_file: Content of the zone file to import
        :param pulumi.Input[builtins.str] zone_name: The name of the domain zone
        """
        if exported_content is not None:
            pulumi.set(__self__, "exported_content", exported_content)
        if zone_file is not None:
            pulumi.set(__self__, "zone_file", zone_file)
        if zone_name is not None:
            pulumi.set(__self__, "zone_name", zone_name)

    @property
    @pulumi.getter(name="exportedContent")
    def exported_content(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Zone file exported from the API
        """
        return pulumi.get(self, "exported_content")

    @exported_content.setter
    def exported_content(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "exported_content", value)

    @property
    @pulumi.getter(name="zoneFile")
    def zone_file(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Content of the zone file to import
        """
        return pulumi.get(self, "zone_file")

    @zone_file.setter
    def zone_file(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_file", value)

    @property
    @pulumi.getter(name="zoneName")
    def zone_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The name of the domain zone
        """
        return pulumi.get(self, "zone_name")

    @zone_name.setter
    def zone_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_name", value)


@pulumi.type_token("ovh:Domain/zoneImport:ZoneImport")
class ZoneImport(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 zone_file: Optional[pulumi.Input[builtins.str]] = None,
                 zone_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Handle a whole DNS zone using a zone file.

        > **WARNING** This resource and resource `Domain.ZoneRecord` should not be used together as `Domain.ZoneImport` controls the whole DNS zone at once.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] zone_file: Content of the zone file to import
        :param pulumi.Input[builtins.str] zone_name: The name of the domain zone
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ZoneImportArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Handle a whole DNS zone using a zone file.

        > **WARNING** This resource and resource `Domain.ZoneRecord` should not be used together as `Domain.ZoneImport` controls the whole DNS zone at once.

        :param str resource_name: The name of the resource.
        :param ZoneImportArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ZoneImportArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 zone_file: Optional[pulumi.Input[builtins.str]] = None,
                 zone_name: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ZoneImportArgs.__new__(ZoneImportArgs)

            if zone_file is None and not opts.urn:
                raise TypeError("Missing required property 'zone_file'")
            __props__.__dict__["zone_file"] = zone_file
            if zone_name is None and not opts.urn:
                raise TypeError("Missing required property 'zone_name'")
            __props__.__dict__["zone_name"] = zone_name
            __props__.__dict__["exported_content"] = None
        super(ZoneImport, __self__).__init__(
            'ovh:Domain/zoneImport:ZoneImport',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            exported_content: Optional[pulumi.Input[builtins.str]] = None,
            zone_file: Optional[pulumi.Input[builtins.str]] = None,
            zone_name: Optional[pulumi.Input[builtins.str]] = None) -> 'ZoneImport':
        """
        Get an existing ZoneImport resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] exported_content: Zone file exported from the API
        :param pulumi.Input[builtins.str] zone_file: Content of the zone file to import
        :param pulumi.Input[builtins.str] zone_name: The name of the domain zone
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ZoneImportState.__new__(_ZoneImportState)

        __props__.__dict__["exported_content"] = exported_content
        __props__.__dict__["zone_file"] = zone_file
        __props__.__dict__["zone_name"] = zone_name
        return ZoneImport(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="exportedContent")
    def exported_content(self) -> pulumi.Output[builtins.str]:
        """
        Zone file exported from the API
        """
        return pulumi.get(self, "exported_content")

    @property
    @pulumi.getter(name="zoneFile")
    def zone_file(self) -> pulumi.Output[builtins.str]:
        """
        Content of the zone file to import
        """
        return pulumi.get(self, "zone_file")

    @property
    @pulumi.getter(name="zoneName")
    def zone_name(self) -> pulumi.Output[builtins.str]:
        """
        The name of the domain zone
        """
        return pulumi.get(self, "zone_name")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetDatabaseLogSubscriptionsResult',
    'AwaitableGetDatabaseLogSubscriptionsResult',
    'get_database_log_subscriptions',
    'get_database_log_subscriptions_output',
]

@pulumi.output_type
class GetDatabaseLogSubscriptionsResult:
    """
    A collection of values returned by getDatabaseLogSubscriptions.
    """
    def __init__(__self__, cluster_id=None, engine=None, id=None, service_name=None, subscription_ids=None):
        if cluster_id and not isinstance(cluster_id, str):
            raise TypeError("Expected argument 'cluster_id' to be a str")
        pulumi.set(__self__, "cluster_id", cluster_id)
        if engine and not isinstance(engine, str):
            raise TypeError("Expected argument 'engine' to be a str")
        pulumi.set(__self__, "engine", engine)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if subscription_ids and not isinstance(subscription_ids, list):
            raise TypeError("Expected argument 'subscription_ids' to be a list")
        pulumi.set(__self__, "subscription_ids", subscription_ids)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter
    def engine(self) -> builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "engine")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        """
        See Argument Reference above.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter(name="subscriptionIds")
    def subscription_ids(self) -> Sequence[builtins.str]:
        """
        The list of log subscription ids of the cluster associated with the project.
        """
        return pulumi.get(self, "subscription_ids")


class AwaitableGetDatabaseLogSubscriptionsResult(GetDatabaseLogSubscriptionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetDatabaseLogSubscriptionsResult(
            cluster_id=self.cluster_id,
            engine=self.engine,
            id=self.id,
            service_name=self.service_name,
            subscription_ids=self.subscription_ids)


def get_database_log_subscriptions(cluster_id: Optional[builtins.str] = None,
                                   engine: Optional[builtins.str] = None,
                                   service_name: Optional[builtins.str] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetDatabaseLogSubscriptionsResult:
    """
    Use this data source to get the list of log subscription for a cluster associated with a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    subscriptions = ovh.CloudProjectDatabase.get_database_log_subscriptions(service_name="XXX",
        engine="YYY",
        cluster_id="ZZZ")
    pulumi.export("subscriptionIds", subscriptions.subscription_ids)
    ```


    :param builtins.str cluster_id: Cluster ID.
    :param builtins.str engine: The database engine for which you want to retrieve a subscription. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['engine'] = engine
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:CloudProjectDatabase/getDatabaseLogSubscriptions:getDatabaseLogSubscriptions', __args__, opts=opts, typ=GetDatabaseLogSubscriptionsResult).value

    return AwaitableGetDatabaseLogSubscriptionsResult(
        cluster_id=pulumi.get(__ret__, 'cluster_id'),
        engine=pulumi.get(__ret__, 'engine'),
        id=pulumi.get(__ret__, 'id'),
        service_name=pulumi.get(__ret__, 'service_name'),
        subscription_ids=pulumi.get(__ret__, 'subscription_ids'))
def get_database_log_subscriptions_output(cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                                          engine: Optional[pulumi.Input[builtins.str]] = None,
                                          service_name: Optional[pulumi.Input[builtins.str]] = None,
                                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetDatabaseLogSubscriptionsResult]:
    """
    Use this data source to get the list of log subscription for a cluster associated with a public cloud project.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    subscriptions = ovh.CloudProjectDatabase.get_database_log_subscriptions(service_name="XXX",
        engine="YYY",
        cluster_id="ZZZ")
    pulumi.export("subscriptionIds", subscriptions.subscription_ids)
    ```


    :param builtins.str cluster_id: Cluster ID.
    :param builtins.str engine: The database engine for which you want to retrieve a subscription. To get a full list of available engine visit. [public documentation](https://docs.ovh.com/gb/en/publiccloud/databases).
    :param builtins.str service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
    """
    __args__ = dict()
    __args__['clusterId'] = cluster_id
    __args__['engine'] = engine
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:CloudProjectDatabase/getDatabaseLogSubscriptions:getDatabaseLogSubscriptions', __args__, opts=opts, typ=GetDatabaseLogSubscriptionsResult)
    return __ret__.apply(lambda __response__: GetDatabaseLogSubscriptionsResult(
        cluster_id=pulumi.get(__response__, 'cluster_id'),
        engine=pulumi.get(__response__, 'engine'),
        id=pulumi.get(__response__, 'id'),
        service_name=pulumi.get(__response__, 'service_name'),
        subscription_ids=pulumi.get(__response__, 'subscription_ids')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
from .. import _utilities
import typing
# Export this package's modules as members:
from .firewall import *
from .firewall_rule import *
from .get_firewall import *
from .get_firewall_rule import *
from .get_mitigation import *
from .get_service import *
from .ip_service import *
from .mitigation import *
from .move import *
from .reverse import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetIdentityUsersResult',
    'AwaitableGetIdentityUsersResult',
    'get_identity_users',
    'get_identity_users_output',
]

@pulumi.output_type
class GetIdentityUsersResult:
    """
    A collection of values returned by getIdentityUsers.
    """
    def __init__(__self__, id=None, users=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if users and not isinstance(users, list):
            raise TypeError("Expected argument 'users' to be a list")
        pulumi.set(__self__, "users", users)

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def users(self) -> Sequence[builtins.str]:
        """
        The list of the user's logins of all the identity users.
        """
        return pulumi.get(self, "users")


class AwaitableGetIdentityUsersResult(GetIdentityUsersResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetIdentityUsersResult(
            id=self.id,
            users=self.users)


def get_identity_users(opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetIdentityUsersResult:
    """
    Use this data source to retrieve list of user logins of the account's identity users.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    users = ovh.Me.get_identity_users()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Me/getIdentityUsers:getIdentityUsers', __args__, opts=opts, typ=GetIdentityUsersResult).value

    return AwaitableGetIdentityUsersResult(
        id=pulumi.get(__ret__, 'id'),
        users=pulumi.get(__ret__, 'users'))
def get_identity_users_output(opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetIdentityUsersResult]:
    """
    Use this data source to retrieve list of user logins of the account's identity users.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    users = ovh.Me.get_identity_users()
    ```
    """
    __args__ = dict()
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Me/getIdentityUsers:getIdentityUsers', __args__, opts=opts, typ=GetIdentityUsersResult)
    return __ret__.apply(lambda __response__: GetIdentityUsersResult(
        id=pulumi.get(__response__, 'id'),
        users=pulumi.get(__response__, 'users')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['ServerArgs', 'Server']

@pulumi.input_type
class ServerArgs:
    def __init__(__self__, *,
                 boot_id: Optional[pulumi.Input[builtins.float]] = None,
                 boot_script: Optional[pulumi.Input[builtins.str]] = None,
                 customizations: Optional[pulumi.Input['ServerCustomizationsArgs']] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 efi_bootloader_path: Optional[pulumi.Input[builtins.str]] = None,
                 keep_service_after_destroy: Optional[pulumi.Input[builtins.bool]] = None,
                 monitoring: Optional[pulumi.Input[builtins.bool]] = None,
                 no_intervention: Optional[pulumi.Input[builtins.bool]] = None,
                 os: Optional[pulumi.Input[builtins.str]] = None,
                 ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
                 plan_options: Optional[pulumi.Input[Sequence[pulumi.Input['ServerPlanOptionArgs']]]] = None,
                 plans: Optional[pulumi.Input[Sequence[pulumi.Input['ServerPlanArgs']]]] = None,
                 prevent_install_on_create: Optional[pulumi.Input[builtins.bool]] = None,
                 prevent_install_on_import: Optional[pulumi.Input[builtins.bool]] = None,
                 properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 rescue_mail: Optional[pulumi.Input[builtins.str]] = None,
                 rescue_ssh_key: Optional[pulumi.Input[builtins.str]] = None,
                 root_device: Optional[pulumi.Input[builtins.str]] = None,
                 run_actions_before_destroys: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 state: Optional[pulumi.Input[builtins.str]] = None,
                 storages: Optional[pulumi.Input[Sequence[pulumi.Input['ServerStorageArgs']]]] = None):
        """
        The set of arguments for constructing a Server resource.
        :param pulumi.Input[builtins.float] boot_id: Boot id of the server
        :param pulumi.Input[builtins.str] boot_script: Boot script of the server
        :param pulumi.Input['ServerCustomizationsArgs'] customizations: OS reinstallation customizations
        :param pulumi.Input[builtins.str] display_name: Resource display name
        :param pulumi.Input[builtins.str] efi_bootloader_path: Path of the EFI bootloader
        :param pulumi.Input[builtins.bool] keep_service_after_destroy: Whether we should avoid terminating the service when destroying the resource
        :param pulumi.Input[builtins.bool] monitoring: Icmp monitoring state
        :param pulumi.Input[builtins.bool] no_intervention: Prevent datacenter intervention
        :param pulumi.Input[builtins.str] os: Operating system
        :param pulumi.Input[builtins.str] ovh_subsidiary: OVH subsidiaries
        :param pulumi.Input[builtins.bool] prevent_install_on_create: Defines whether the server should not be reinstalled after creating the resource
        :param pulumi.Input[builtins.bool] prevent_install_on_import: Defines whether the server should not be reinstalled when importing the resource
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] properties: Arbitrary properties to pass to cloud-init's config drive datasource
        :param pulumi.Input[builtins.str] rescue_mail: Rescue mail of the server
        :param pulumi.Input[builtins.str] rescue_ssh_key: Public SSH Key used in the rescue mode
        :param pulumi.Input[builtins.str] root_device: Root device of the server
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] run_actions_before_destroys: Actions to run before destroying the resource
        :param pulumi.Input[builtins.str] service_name: The service_name of your dedicated server
        :param pulumi.Input[builtins.str] state: All states a Dedicated can be in (error, hacked, hackedBlocked, ok)
        :param pulumi.Input[Sequence[pulumi.Input['ServerStorageArgs']]] storages: OS reinstallation storage configurations
        """
        if boot_id is not None:
            pulumi.set(__self__, "boot_id", boot_id)
        if boot_script is not None:
            pulumi.set(__self__, "boot_script", boot_script)
        if customizations is not None:
            pulumi.set(__self__, "customizations", customizations)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if efi_bootloader_path is not None:
            pulumi.set(__self__, "efi_bootloader_path", efi_bootloader_path)
        if keep_service_after_destroy is not None:
            pulumi.set(__self__, "keep_service_after_destroy", keep_service_after_destroy)
        if monitoring is not None:
            pulumi.set(__self__, "monitoring", monitoring)
        if no_intervention is not None:
            pulumi.set(__self__, "no_intervention", no_intervention)
        if os is not None:
            pulumi.set(__self__, "os", os)
        if ovh_subsidiary is not None:
            pulumi.set(__self__, "ovh_subsidiary", ovh_subsidiary)
        if plan_options is not None:
            pulumi.set(__self__, "plan_options", plan_options)
        if plans is not None:
            pulumi.set(__self__, "plans", plans)
        if prevent_install_on_create is not None:
            pulumi.set(__self__, "prevent_install_on_create", prevent_install_on_create)
        if prevent_install_on_import is not None:
            pulumi.set(__self__, "prevent_install_on_import", prevent_install_on_import)
        if properties is not None:
            pulumi.set(__self__, "properties", properties)
        if rescue_mail is not None:
            pulumi.set(__self__, "rescue_mail", rescue_mail)
        if rescue_ssh_key is not None:
            pulumi.set(__self__, "rescue_ssh_key", rescue_ssh_key)
        if root_device is not None:
            pulumi.set(__self__, "root_device", root_device)
        if run_actions_before_destroys is not None:
            pulumi.set(__self__, "run_actions_before_destroys", run_actions_before_destroys)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if storages is not None:
            pulumi.set(__self__, "storages", storages)

    @property
    @pulumi.getter(name="bootId")
    def boot_id(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Boot id of the server
        """
        return pulumi.get(self, "boot_id")

    @boot_id.setter
    def boot_id(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "boot_id", value)

    @property
    @pulumi.getter(name="bootScript")
    def boot_script(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Boot script of the server
        """
        return pulumi.get(self, "boot_script")

    @boot_script.setter
    def boot_script(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "boot_script", value)

    @property
    @pulumi.getter
    def customizations(self) -> Optional[pulumi.Input['ServerCustomizationsArgs']]:
        """
        OS reinstallation customizations
        """
        return pulumi.get(self, "customizations")

    @customizations.setter
    def customizations(self, value: Optional[pulumi.Input['ServerCustomizationsArgs']]):
        pulumi.set(self, "customizations", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Resource display name
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="efiBootloaderPath")
    def efi_bootloader_path(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Path of the EFI bootloader
        """
        return pulumi.get(self, "efi_bootloader_path")

    @efi_bootloader_path.setter
    def efi_bootloader_path(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "efi_bootloader_path", value)

    @property
    @pulumi.getter(name="keepServiceAfterDestroy")
    def keep_service_after_destroy(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether we should avoid terminating the service when destroying the resource
        """
        return pulumi.get(self, "keep_service_after_destroy")

    @keep_service_after_destroy.setter
    def keep_service_after_destroy(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "keep_service_after_destroy", value)

    @property
    @pulumi.getter
    def monitoring(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Icmp monitoring state
        """
        return pulumi.get(self, "monitoring")

    @monitoring.setter
    def monitoring(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "monitoring", value)

    @property
    @pulumi.getter(name="noIntervention")
    def no_intervention(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Prevent datacenter intervention
        """
        return pulumi.get(self, "no_intervention")

    @no_intervention.setter
    def no_intervention(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "no_intervention", value)

    @property
    @pulumi.getter
    def os(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Operating system
        """
        return pulumi.get(self, "os")

    @os.setter
    def os(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "os", value)

    @property
    @pulumi.getter(name="ovhSubsidiary")
    def ovh_subsidiary(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        OVH subsidiaries
        """
        return pulumi.get(self, "ovh_subsidiary")

    @ovh_subsidiary.setter
    def ovh_subsidiary(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ovh_subsidiary", value)

    @property
    @pulumi.getter(name="planOptions")
    def plan_options(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerPlanOptionArgs']]]]:
        return pulumi.get(self, "plan_options")

    @plan_options.setter
    def plan_options(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerPlanOptionArgs']]]]):
        pulumi.set(self, "plan_options", value)

    @property
    @pulumi.getter
    def plans(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerPlanArgs']]]]:
        return pulumi.get(self, "plans")

    @plans.setter
    def plans(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerPlanArgs']]]]):
        pulumi.set(self, "plans", value)

    @property
    @pulumi.getter(name="preventInstallOnCreate")
    def prevent_install_on_create(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Defines whether the server should not be reinstalled after creating the resource
        """
        return pulumi.get(self, "prevent_install_on_create")

    @prevent_install_on_create.setter
    def prevent_install_on_create(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "prevent_install_on_create", value)

    @property
    @pulumi.getter(name="preventInstallOnImport")
    def prevent_install_on_import(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Defines whether the server should not be reinstalled when importing the resource
        """
        return pulumi.get(self, "prevent_install_on_import")

    @prevent_install_on_import.setter
    def prevent_install_on_import(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "prevent_install_on_import", value)

    @property
    @pulumi.getter
    def properties(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Arbitrary properties to pass to cloud-init's config drive datasource
        """
        return pulumi.get(self, "properties")

    @properties.setter
    def properties(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "properties", value)

    @property
    @pulumi.getter(name="rescueMail")
    def rescue_mail(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rescue mail of the server
        """
        return pulumi.get(self, "rescue_mail")

    @rescue_mail.setter
    def rescue_mail(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rescue_mail", value)

    @property
    @pulumi.getter(name="rescueSshKey")
    def rescue_ssh_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Public SSH Key used in the rescue mode
        """
        return pulumi.get(self, "rescue_ssh_key")

    @rescue_ssh_key.setter
    def rescue_ssh_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rescue_ssh_key", value)

    @property
    @pulumi.getter(name="rootDevice")
    def root_device(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Root device of the server
        """
        return pulumi.get(self, "root_device")

    @root_device.setter
    def root_device(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "root_device", value)

    @property
    @pulumi.getter(name="runActionsBeforeDestroys")
    def run_actions_before_destroys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Actions to run before destroying the resource
        """
        return pulumi.get(self, "run_actions_before_destroys")

    @run_actions_before_destroys.setter
    def run_actions_before_destroys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "run_actions_before_destroys", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The service_name of your dedicated server
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        All states a Dedicated can be in (error, hacked, hackedBlocked, ok)
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter
    def storages(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerStorageArgs']]]]:
        """
        OS reinstallation storage configurations
        """
        return pulumi.get(self, "storages")

    @storages.setter
    def storages(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerStorageArgs']]]]):
        pulumi.set(self, "storages", value)


@pulumi.input_type
class _ServerState:
    def __init__(__self__, *,
                 availability_zone: Optional[pulumi.Input[builtins.str]] = None,
                 boot_id: Optional[pulumi.Input[builtins.float]] = None,
                 boot_script: Optional[pulumi.Input[builtins.str]] = None,
                 commercial_range: Optional[pulumi.Input[builtins.str]] = None,
                 customizations: Optional[pulumi.Input['ServerCustomizationsArgs']] = None,
                 datacenter: Optional[pulumi.Input[builtins.str]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 efi_bootloader_path: Optional[pulumi.Input[builtins.str]] = None,
                 iam: Optional[pulumi.Input['ServerIamArgs']] = None,
                 ip: Optional[pulumi.Input[builtins.str]] = None,
                 keep_service_after_destroy: Optional[pulumi.Input[builtins.bool]] = None,
                 link_speed: Optional[pulumi.Input[builtins.float]] = None,
                 monitoring: Optional[pulumi.Input[builtins.bool]] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 new_upgrade_system: Optional[pulumi.Input[builtins.bool]] = None,
                 no_intervention: Optional[pulumi.Input[builtins.bool]] = None,
                 order: Optional[pulumi.Input['ServerOrderArgs']] = None,
                 os: Optional[pulumi.Input[builtins.str]] = None,
                 ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
                 plan_options: Optional[pulumi.Input[Sequence[pulumi.Input['ServerPlanOptionArgs']]]] = None,
                 plans: Optional[pulumi.Input[Sequence[pulumi.Input['ServerPlanArgs']]]] = None,
                 power_state: Optional[pulumi.Input[builtins.str]] = None,
                 prevent_install_on_create: Optional[pulumi.Input[builtins.bool]] = None,
                 prevent_install_on_import: Optional[pulumi.Input[builtins.bool]] = None,
                 professional_use: Optional[pulumi.Input[builtins.bool]] = None,
                 properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 rack: Optional[pulumi.Input[builtins.str]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 rescue_mail: Optional[pulumi.Input[builtins.str]] = None,
                 rescue_ssh_key: Optional[pulumi.Input[builtins.str]] = None,
                 reverse: Optional[pulumi.Input[builtins.str]] = None,
                 root_device: Optional[pulumi.Input[builtins.str]] = None,
                 run_actions_before_destroys: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 server_id: Optional[pulumi.Input[builtins.float]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 state: Optional[pulumi.Input[builtins.str]] = None,
                 storages: Optional[pulumi.Input[Sequence[pulumi.Input['ServerStorageArgs']]]] = None,
                 support_level: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Server resources.
        :param pulumi.Input[builtins.str] availability_zone: Dedicated AZ localisation
        :param pulumi.Input[builtins.float] boot_id: Boot id of the server
        :param pulumi.Input[builtins.str] boot_script: Boot script of the server
        :param pulumi.Input[builtins.str] commercial_range: Dedicated server commercial range
        :param pulumi.Input['ServerCustomizationsArgs'] customizations: OS reinstallation customizations
        :param pulumi.Input[builtins.str] datacenter: Dedicated datacenter localisation (bhs1,bhs2,...)
        :param pulumi.Input[builtins.str] display_name: Resource display name
        :param pulumi.Input[builtins.str] efi_bootloader_path: Path of the EFI bootloader
        :param pulumi.Input['ServerIamArgs'] iam: IAM resource information
        :param pulumi.Input[builtins.str] ip: Dedicated server ip (IPv4)
        :param pulumi.Input[builtins.bool] keep_service_after_destroy: Whether we should avoid terminating the service when destroying the resource
        :param pulumi.Input[builtins.float] link_speed: Link speed of the server
        :param pulumi.Input[builtins.bool] monitoring: Icmp monitoring state
        :param pulumi.Input[builtins.str] name: Dedicated server name
        :param pulumi.Input[builtins.bool] no_intervention: Prevent datacenter intervention
        :param pulumi.Input['ServerOrderArgs'] order: Details about an Order
        :param pulumi.Input[builtins.str] os: Operating system
        :param pulumi.Input[builtins.str] ovh_subsidiary: OVH subsidiaries
        :param pulumi.Input[builtins.str] power_state: Power state of the server (poweron, poweroff)
        :param pulumi.Input[builtins.bool] prevent_install_on_create: Defines whether the server should not be reinstalled after creating the resource
        :param pulumi.Input[builtins.bool] prevent_install_on_import: Defines whether the server should not be reinstalled when importing the resource
        :param pulumi.Input[builtins.bool] professional_use: Does this server have professional use option
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] properties: Arbitrary properties to pass to cloud-init's config drive datasource
        :param pulumi.Input[builtins.str] rack: Rack id of the server
        :param pulumi.Input[builtins.str] region: Dedicated region localisation
        :param pulumi.Input[builtins.str] rescue_mail: Rescue mail of the server
        :param pulumi.Input[builtins.str] rescue_ssh_key: Public SSH Key used in the rescue mode
        :param pulumi.Input[builtins.str] reverse: Dedicated server reverse
        :param pulumi.Input[builtins.str] root_device: Root device of the server
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] run_actions_before_destroys: Actions to run before destroying the resource
        :param pulumi.Input[builtins.float] server_id: Server id
        :param pulumi.Input[builtins.str] service_name: The service_name of your dedicated server
        :param pulumi.Input[builtins.str] state: All states a Dedicated can be in (error, hacked, hackedBlocked, ok)
        :param pulumi.Input[Sequence[pulumi.Input['ServerStorageArgs']]] storages: OS reinstallation storage configurations
        :param pulumi.Input[builtins.str] support_level: Dedicated server support level (critical, fastpath, gs, pro)
        """
        if availability_zone is not None:
            pulumi.set(__self__, "availability_zone", availability_zone)
        if boot_id is not None:
            pulumi.set(__self__, "boot_id", boot_id)
        if boot_script is not None:
            pulumi.set(__self__, "boot_script", boot_script)
        if commercial_range is not None:
            pulumi.set(__self__, "commercial_range", commercial_range)
        if customizations is not None:
            pulumi.set(__self__, "customizations", customizations)
        if datacenter is not None:
            pulumi.set(__self__, "datacenter", datacenter)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if efi_bootloader_path is not None:
            pulumi.set(__self__, "efi_bootloader_path", efi_bootloader_path)
        if iam is not None:
            pulumi.set(__self__, "iam", iam)
        if ip is not None:
            pulumi.set(__self__, "ip", ip)
        if keep_service_after_destroy is not None:
            pulumi.set(__self__, "keep_service_after_destroy", keep_service_after_destroy)
        if link_speed is not None:
            pulumi.set(__self__, "link_speed", link_speed)
        if monitoring is not None:
            pulumi.set(__self__, "monitoring", monitoring)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if new_upgrade_system is not None:
            pulumi.set(__self__, "new_upgrade_system", new_upgrade_system)
        if no_intervention is not None:
            pulumi.set(__self__, "no_intervention", no_intervention)
        if order is not None:
            pulumi.set(__self__, "order", order)
        if os is not None:
            pulumi.set(__self__, "os", os)
        if ovh_subsidiary is not None:
            pulumi.set(__self__, "ovh_subsidiary", ovh_subsidiary)
        if plan_options is not None:
            pulumi.set(__self__, "plan_options", plan_options)
        if plans is not None:
            pulumi.set(__self__, "plans", plans)
        if power_state is not None:
            pulumi.set(__self__, "power_state", power_state)
        if prevent_install_on_create is not None:
            pulumi.set(__self__, "prevent_install_on_create", prevent_install_on_create)
        if prevent_install_on_import is not None:
            pulumi.set(__self__, "prevent_install_on_import", prevent_install_on_import)
        if professional_use is not None:
            pulumi.set(__self__, "professional_use", professional_use)
        if properties is not None:
            pulumi.set(__self__, "properties", properties)
        if rack is not None:
            pulumi.set(__self__, "rack", rack)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if rescue_mail is not None:
            pulumi.set(__self__, "rescue_mail", rescue_mail)
        if rescue_ssh_key is not None:
            pulumi.set(__self__, "rescue_ssh_key", rescue_ssh_key)
        if reverse is not None:
            pulumi.set(__self__, "reverse", reverse)
        if root_device is not None:
            pulumi.set(__self__, "root_device", root_device)
        if run_actions_before_destroys is not None:
            pulumi.set(__self__, "run_actions_before_destroys", run_actions_before_destroys)
        if server_id is not None:
            pulumi.set(__self__, "server_id", server_id)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if storages is not None:
            pulumi.set(__self__, "storages", storages)
        if support_level is not None:
            pulumi.set(__self__, "support_level", support_level)

    @property
    @pulumi.getter(name="availabilityZone")
    def availability_zone(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Dedicated AZ localisation
        """
        return pulumi.get(self, "availability_zone")

    @availability_zone.setter
    def availability_zone(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "availability_zone", value)

    @property
    @pulumi.getter(name="bootId")
    def boot_id(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Boot id of the server
        """
        return pulumi.get(self, "boot_id")

    @boot_id.setter
    def boot_id(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "boot_id", value)

    @property
    @pulumi.getter(name="bootScript")
    def boot_script(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Boot script of the server
        """
        return pulumi.get(self, "boot_script")

    @boot_script.setter
    def boot_script(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "boot_script", value)

    @property
    @pulumi.getter(name="commercialRange")
    def commercial_range(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Dedicated server commercial range
        """
        return pulumi.get(self, "commercial_range")

    @commercial_range.setter
    def commercial_range(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "commercial_range", value)

    @property
    @pulumi.getter
    def customizations(self) -> Optional[pulumi.Input['ServerCustomizationsArgs']]:
        """
        OS reinstallation customizations
        """
        return pulumi.get(self, "customizations")

    @customizations.setter
    def customizations(self, value: Optional[pulumi.Input['ServerCustomizationsArgs']]):
        pulumi.set(self, "customizations", value)

    @property
    @pulumi.getter
    def datacenter(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Dedicated datacenter localisation (bhs1,bhs2,...)
        """
        return pulumi.get(self, "datacenter")

    @datacenter.setter
    def datacenter(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "datacenter", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Resource display name
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="efiBootloaderPath")
    def efi_bootloader_path(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Path of the EFI bootloader
        """
        return pulumi.get(self, "efi_bootloader_path")

    @efi_bootloader_path.setter
    def efi_bootloader_path(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "efi_bootloader_path", value)

    @property
    @pulumi.getter
    def iam(self) -> Optional[pulumi.Input['ServerIamArgs']]:
        """
        IAM resource information
        """
        return pulumi.get(self, "iam")

    @iam.setter
    def iam(self, value: Optional[pulumi.Input['ServerIamArgs']]):
        pulumi.set(self, "iam", value)

    @property
    @pulumi.getter
    def ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Dedicated server ip (IPv4)
        """
        return pulumi.get(self, "ip")

    @ip.setter
    def ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ip", value)

    @property
    @pulumi.getter(name="keepServiceAfterDestroy")
    def keep_service_after_destroy(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Whether we should avoid terminating the service when destroying the resource
        """
        return pulumi.get(self, "keep_service_after_destroy")

    @keep_service_after_destroy.setter
    def keep_service_after_destroy(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "keep_service_after_destroy", value)

    @property
    @pulumi.getter(name="linkSpeed")
    def link_speed(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Link speed of the server
        """
        return pulumi.get(self, "link_speed")

    @link_speed.setter
    def link_speed(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "link_speed", value)

    @property
    @pulumi.getter
    def monitoring(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Icmp monitoring state
        """
        return pulumi.get(self, "monitoring")

    @monitoring.setter
    def monitoring(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "monitoring", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Dedicated server name
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="newUpgradeSystem")
    def new_upgrade_system(self) -> Optional[pulumi.Input[builtins.bool]]:
        return pulumi.get(self, "new_upgrade_system")

    @new_upgrade_system.setter
    def new_upgrade_system(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "new_upgrade_system", value)

    @property
    @pulumi.getter(name="noIntervention")
    def no_intervention(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Prevent datacenter intervention
        """
        return pulumi.get(self, "no_intervention")

    @no_intervention.setter
    def no_intervention(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "no_intervention", value)

    @property
    @pulumi.getter
    def order(self) -> Optional[pulumi.Input['ServerOrderArgs']]:
        """
        Details about an Order
        """
        return pulumi.get(self, "order")

    @order.setter
    def order(self, value: Optional[pulumi.Input['ServerOrderArgs']]):
        pulumi.set(self, "order", value)

    @property
    @pulumi.getter
    def os(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Operating system
        """
        return pulumi.get(self, "os")

    @os.setter
    def os(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "os", value)

    @property
    @pulumi.getter(name="ovhSubsidiary")
    def ovh_subsidiary(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        OVH subsidiaries
        """
        return pulumi.get(self, "ovh_subsidiary")

    @ovh_subsidiary.setter
    def ovh_subsidiary(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "ovh_subsidiary", value)

    @property
    @pulumi.getter(name="planOptions")
    def plan_options(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerPlanOptionArgs']]]]:
        return pulumi.get(self, "plan_options")

    @plan_options.setter
    def plan_options(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerPlanOptionArgs']]]]):
        pulumi.set(self, "plan_options", value)

    @property
    @pulumi.getter
    def plans(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerPlanArgs']]]]:
        return pulumi.get(self, "plans")

    @plans.setter
    def plans(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerPlanArgs']]]]):
        pulumi.set(self, "plans", value)

    @property
    @pulumi.getter(name="powerState")
    def power_state(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Power state of the server (poweron, poweroff)
        """
        return pulumi.get(self, "power_state")

    @power_state.setter
    def power_state(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "power_state", value)

    @property
    @pulumi.getter(name="preventInstallOnCreate")
    def prevent_install_on_create(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Defines whether the server should not be reinstalled after creating the resource
        """
        return pulumi.get(self, "prevent_install_on_create")

    @prevent_install_on_create.setter
    def prevent_install_on_create(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "prevent_install_on_create", value)

    @property
    @pulumi.getter(name="preventInstallOnImport")
    def prevent_install_on_import(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Defines whether the server should not be reinstalled when importing the resource
        """
        return pulumi.get(self, "prevent_install_on_import")

    @prevent_install_on_import.setter
    def prevent_install_on_import(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "prevent_install_on_import", value)

    @property
    @pulumi.getter(name="professionalUse")
    def professional_use(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Does this server have professional use option
        """
        return pulumi.get(self, "professional_use")

    @professional_use.setter
    def professional_use(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "professional_use", value)

    @property
    @pulumi.getter
    def properties(self) -> Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]:
        """
        Arbitrary properties to pass to cloud-init's config drive datasource
        """
        return pulumi.get(self, "properties")

    @properties.setter
    def properties(self, value: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "properties", value)

    @property
    @pulumi.getter
    def rack(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rack id of the server
        """
        return pulumi.get(self, "rack")

    @rack.setter
    def rack(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rack", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Dedicated region localisation
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="rescueMail")
    def rescue_mail(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Rescue mail of the server
        """
        return pulumi.get(self, "rescue_mail")

    @rescue_mail.setter
    def rescue_mail(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rescue_mail", value)

    @property
    @pulumi.getter(name="rescueSshKey")
    def rescue_ssh_key(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Public SSH Key used in the rescue mode
        """
        return pulumi.get(self, "rescue_ssh_key")

    @rescue_ssh_key.setter
    def rescue_ssh_key(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "rescue_ssh_key", value)

    @property
    @pulumi.getter
    def reverse(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Dedicated server reverse
        """
        return pulumi.get(self, "reverse")

    @reverse.setter
    def reverse(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "reverse", value)

    @property
    @pulumi.getter(name="rootDevice")
    def root_device(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Root device of the server
        """
        return pulumi.get(self, "root_device")

    @root_device.setter
    def root_device(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "root_device", value)

    @property
    @pulumi.getter(name="runActionsBeforeDestroys")
    def run_actions_before_destroys(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        Actions to run before destroying the resource
        """
        return pulumi.get(self, "run_actions_before_destroys")

    @run_actions_before_destroys.setter
    def run_actions_before_destroys(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "run_actions_before_destroys", value)

    @property
    @pulumi.getter(name="serverId")
    def server_id(self) -> Optional[pulumi.Input[builtins.float]]:
        """
        Server id
        """
        return pulumi.get(self, "server_id")

    @server_id.setter
    def server_id(self, value: Optional[pulumi.Input[builtins.float]]):
        pulumi.set(self, "server_id", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The service_name of your dedicated server
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        All states a Dedicated can be in (error, hacked, hackedBlocked, ok)
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter
    def storages(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['ServerStorageArgs']]]]:
        """
        OS reinstallation storage configurations
        """
        return pulumi.get(self, "storages")

    @storages.setter
    def storages(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['ServerStorageArgs']]]]):
        pulumi.set(self, "storages", value)

    @property
    @pulumi.getter(name="supportLevel")
    def support_level(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Dedicated server support level (critical, fastpath, gs, pro)
        """
        return pulumi.get(self, "support_level")

    @support_level.setter
    def support_level(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "support_level", value)


@pulumi.type_token("ovh:Dedicated/server:Server")
class Server(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 boot_id: Optional[pulumi.Input[builtins.float]] = None,
                 boot_script: Optional[pulumi.Input[builtins.str]] = None,
                 customizations: Optional[pulumi.Input[Union['ServerCustomizationsArgs', 'ServerCustomizationsArgsDict']]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 efi_bootloader_path: Optional[pulumi.Input[builtins.str]] = None,
                 keep_service_after_destroy: Optional[pulumi.Input[builtins.bool]] = None,
                 monitoring: Optional[pulumi.Input[builtins.bool]] = None,
                 no_intervention: Optional[pulumi.Input[builtins.bool]] = None,
                 os: Optional[pulumi.Input[builtins.str]] = None,
                 ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
                 plan_options: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerPlanOptionArgs', 'ServerPlanOptionArgsDict']]]]] = None,
                 plans: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerPlanArgs', 'ServerPlanArgsDict']]]]] = None,
                 prevent_install_on_create: Optional[pulumi.Input[builtins.bool]] = None,
                 prevent_install_on_import: Optional[pulumi.Input[builtins.bool]] = None,
                 properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 rescue_mail: Optional[pulumi.Input[builtins.str]] = None,
                 rescue_ssh_key: Optional[pulumi.Input[builtins.str]] = None,
                 root_device: Optional[pulumi.Input[builtins.str]] = None,
                 run_actions_before_destroys: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 state: Optional[pulumi.Input[builtins.str]] = None,
                 storages: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerStorageArgs', 'ServerStorageArgsDict']]]]] = None,
                 __props__=None):
        """
        ## Import

        Dedicated servers can be imported using the `service_name`. Using the following configuration:

        terraform

        import {

          to = ovh_dedicated_server.server

          id = "<service name>"

        }

        You can then run:

        bash

        pulumi preview -generate-config-out=dedicated.tf

        pulumi up

        The file `dedicated.tf` will then contain the imported resource's configuration, that can be copied next to the `import` block above. See https://developer.hashicorp.com/terraform/language/import/generating-configuration for more details.

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.float] boot_id: Boot id of the server
        :param pulumi.Input[builtins.str] boot_script: Boot script of the server
        :param pulumi.Input[Union['ServerCustomizationsArgs', 'ServerCustomizationsArgsDict']] customizations: OS reinstallation customizations
        :param pulumi.Input[builtins.str] display_name: Resource display name
        :param pulumi.Input[builtins.str] efi_bootloader_path: Path of the EFI bootloader
        :param pulumi.Input[builtins.bool] keep_service_after_destroy: Whether we should avoid terminating the service when destroying the resource
        :param pulumi.Input[builtins.bool] monitoring: Icmp monitoring state
        :param pulumi.Input[builtins.bool] no_intervention: Prevent datacenter intervention
        :param pulumi.Input[builtins.str] os: Operating system
        :param pulumi.Input[builtins.str] ovh_subsidiary: OVH subsidiaries
        :param pulumi.Input[builtins.bool] prevent_install_on_create: Defines whether the server should not be reinstalled after creating the resource
        :param pulumi.Input[builtins.bool] prevent_install_on_import: Defines whether the server should not be reinstalled when importing the resource
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] properties: Arbitrary properties to pass to cloud-init's config drive datasource
        :param pulumi.Input[builtins.str] rescue_mail: Rescue mail of the server
        :param pulumi.Input[builtins.str] rescue_ssh_key: Public SSH Key used in the rescue mode
        :param pulumi.Input[builtins.str] root_device: Root device of the server
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] run_actions_before_destroys: Actions to run before destroying the resource
        :param pulumi.Input[builtins.str] service_name: The service_name of your dedicated server
        :param pulumi.Input[builtins.str] state: All states a Dedicated can be in (error, hacked, hackedBlocked, ok)
        :param pulumi.Input[Sequence[pulumi.Input[Union['ServerStorageArgs', 'ServerStorageArgsDict']]]] storages: OS reinstallation storage configurations
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[ServerArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        Dedicated servers can be imported using the `service_name`. Using the following configuration:

        terraform

        import {

          to = ovh_dedicated_server.server

          id = "<service name>"

        }

        You can then run:

        bash

        pulumi preview -generate-config-out=dedicated.tf

        pulumi up

        The file `dedicated.tf` will then contain the imported resource's configuration, that can be copied next to the `import` block above. See https://developer.hashicorp.com/terraform/language/import/generating-configuration for more details.

        :param str resource_name: The name of the resource.
        :param ServerArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ServerArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 boot_id: Optional[pulumi.Input[builtins.float]] = None,
                 boot_script: Optional[pulumi.Input[builtins.str]] = None,
                 customizations: Optional[pulumi.Input[Union['ServerCustomizationsArgs', 'ServerCustomizationsArgsDict']]] = None,
                 display_name: Optional[pulumi.Input[builtins.str]] = None,
                 efi_bootloader_path: Optional[pulumi.Input[builtins.str]] = None,
                 keep_service_after_destroy: Optional[pulumi.Input[builtins.bool]] = None,
                 monitoring: Optional[pulumi.Input[builtins.bool]] = None,
                 no_intervention: Optional[pulumi.Input[builtins.bool]] = None,
                 os: Optional[pulumi.Input[builtins.str]] = None,
                 ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
                 plan_options: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerPlanOptionArgs', 'ServerPlanOptionArgsDict']]]]] = None,
                 plans: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerPlanArgs', 'ServerPlanArgsDict']]]]] = None,
                 prevent_install_on_create: Optional[pulumi.Input[builtins.bool]] = None,
                 prevent_install_on_import: Optional[pulumi.Input[builtins.bool]] = None,
                 properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
                 rescue_mail: Optional[pulumi.Input[builtins.str]] = None,
                 rescue_ssh_key: Optional[pulumi.Input[builtins.str]] = None,
                 root_device: Optional[pulumi.Input[builtins.str]] = None,
                 run_actions_before_destroys: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 state: Optional[pulumi.Input[builtins.str]] = None,
                 storages: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerStorageArgs', 'ServerStorageArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ServerArgs.__new__(ServerArgs)

            __props__.__dict__["boot_id"] = boot_id
            __props__.__dict__["boot_script"] = boot_script
            __props__.__dict__["customizations"] = customizations
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["efi_bootloader_path"] = efi_bootloader_path
            __props__.__dict__["keep_service_after_destroy"] = keep_service_after_destroy
            __props__.__dict__["monitoring"] = monitoring
            __props__.__dict__["no_intervention"] = no_intervention
            __props__.__dict__["os"] = os
            __props__.__dict__["ovh_subsidiary"] = ovh_subsidiary
            __props__.__dict__["plan_options"] = plan_options
            __props__.__dict__["plans"] = plans
            __props__.__dict__["prevent_install_on_create"] = prevent_install_on_create
            __props__.__dict__["prevent_install_on_import"] = prevent_install_on_import
            __props__.__dict__["properties"] = properties
            __props__.__dict__["rescue_mail"] = rescue_mail
            __props__.__dict__["rescue_ssh_key"] = rescue_ssh_key
            __props__.__dict__["root_device"] = root_device
            __props__.__dict__["run_actions_before_destroys"] = run_actions_before_destroys
            __props__.__dict__["service_name"] = service_name
            __props__.__dict__["state"] = state
            __props__.__dict__["storages"] = storages
            __props__.__dict__["availability_zone"] = None
            __props__.__dict__["commercial_range"] = None
            __props__.__dict__["datacenter"] = None
            __props__.__dict__["iam"] = None
            __props__.__dict__["ip"] = None
            __props__.__dict__["link_speed"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["new_upgrade_system"] = None
            __props__.__dict__["order"] = None
            __props__.__dict__["power_state"] = None
            __props__.__dict__["professional_use"] = None
            __props__.__dict__["rack"] = None
            __props__.__dict__["region"] = None
            __props__.__dict__["reverse"] = None
            __props__.__dict__["server_id"] = None
            __props__.__dict__["support_level"] = None
        super(Server, __self__).__init__(
            'ovh:Dedicated/server:Server',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            availability_zone: Optional[pulumi.Input[builtins.str]] = None,
            boot_id: Optional[pulumi.Input[builtins.float]] = None,
            boot_script: Optional[pulumi.Input[builtins.str]] = None,
            commercial_range: Optional[pulumi.Input[builtins.str]] = None,
            customizations: Optional[pulumi.Input[Union['ServerCustomizationsArgs', 'ServerCustomizationsArgsDict']]] = None,
            datacenter: Optional[pulumi.Input[builtins.str]] = None,
            display_name: Optional[pulumi.Input[builtins.str]] = None,
            efi_bootloader_path: Optional[pulumi.Input[builtins.str]] = None,
            iam: Optional[pulumi.Input[Union['ServerIamArgs', 'ServerIamArgsDict']]] = None,
            ip: Optional[pulumi.Input[builtins.str]] = None,
            keep_service_after_destroy: Optional[pulumi.Input[builtins.bool]] = None,
            link_speed: Optional[pulumi.Input[builtins.float]] = None,
            monitoring: Optional[pulumi.Input[builtins.bool]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            new_upgrade_system: Optional[pulumi.Input[builtins.bool]] = None,
            no_intervention: Optional[pulumi.Input[builtins.bool]] = None,
            order: Optional[pulumi.Input[Union['ServerOrderArgs', 'ServerOrderArgsDict']]] = None,
            os: Optional[pulumi.Input[builtins.str]] = None,
            ovh_subsidiary: Optional[pulumi.Input[builtins.str]] = None,
            plan_options: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerPlanOptionArgs', 'ServerPlanOptionArgsDict']]]]] = None,
            plans: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerPlanArgs', 'ServerPlanArgsDict']]]]] = None,
            power_state: Optional[pulumi.Input[builtins.str]] = None,
            prevent_install_on_create: Optional[pulumi.Input[builtins.bool]] = None,
            prevent_install_on_import: Optional[pulumi.Input[builtins.bool]] = None,
            professional_use: Optional[pulumi.Input[builtins.bool]] = None,
            properties: Optional[pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]]] = None,
            rack: Optional[pulumi.Input[builtins.str]] = None,
            region: Optional[pulumi.Input[builtins.str]] = None,
            rescue_mail: Optional[pulumi.Input[builtins.str]] = None,
            rescue_ssh_key: Optional[pulumi.Input[builtins.str]] = None,
            reverse: Optional[pulumi.Input[builtins.str]] = None,
            root_device: Optional[pulumi.Input[builtins.str]] = None,
            run_actions_before_destroys: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            server_id: Optional[pulumi.Input[builtins.float]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            state: Optional[pulumi.Input[builtins.str]] = None,
            storages: Optional[pulumi.Input[Sequence[pulumi.Input[Union['ServerStorageArgs', 'ServerStorageArgsDict']]]]] = None,
            support_level: Optional[pulumi.Input[builtins.str]] = None) -> 'Server':
        """
        Get an existing Server resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] availability_zone: Dedicated AZ localisation
        :param pulumi.Input[builtins.float] boot_id: Boot id of the server
        :param pulumi.Input[builtins.str] boot_script: Boot script of the server
        :param pulumi.Input[builtins.str] commercial_range: Dedicated server commercial range
        :param pulumi.Input[Union['ServerCustomizationsArgs', 'ServerCustomizationsArgsDict']] customizations: OS reinstallation customizations
        :param pulumi.Input[builtins.str] datacenter: Dedicated datacenter localisation (bhs1,bhs2,...)
        :param pulumi.Input[builtins.str] display_name: Resource display name
        :param pulumi.Input[builtins.str] efi_bootloader_path: Path of the EFI bootloader
        :param pulumi.Input[Union['ServerIamArgs', 'ServerIamArgsDict']] iam: IAM resource information
        :param pulumi.Input[builtins.str] ip: Dedicated server ip (IPv4)
        :param pulumi.Input[builtins.bool] keep_service_after_destroy: Whether we should avoid terminating the service when destroying the resource
        :param pulumi.Input[builtins.float] link_speed: Link speed of the server
        :param pulumi.Input[builtins.bool] monitoring: Icmp monitoring state
        :param pulumi.Input[builtins.str] name: Dedicated server name
        :param pulumi.Input[builtins.bool] no_intervention: Prevent datacenter intervention
        :param pulumi.Input[Union['ServerOrderArgs', 'ServerOrderArgsDict']] order: Details about an Order
        :param pulumi.Input[builtins.str] os: Operating system
        :param pulumi.Input[builtins.str] ovh_subsidiary: OVH subsidiaries
        :param pulumi.Input[builtins.str] power_state: Power state of the server (poweron, poweroff)
        :param pulumi.Input[builtins.bool] prevent_install_on_create: Defines whether the server should not be reinstalled after creating the resource
        :param pulumi.Input[builtins.bool] prevent_install_on_import: Defines whether the server should not be reinstalled when importing the resource
        :param pulumi.Input[builtins.bool] professional_use: Does this server have professional use option
        :param pulumi.Input[Mapping[str, pulumi.Input[builtins.str]]] properties: Arbitrary properties to pass to cloud-init's config drive datasource
        :param pulumi.Input[builtins.str] rack: Rack id of the server
        :param pulumi.Input[builtins.str] region: Dedicated region localisation
        :param pulumi.Input[builtins.str] rescue_mail: Rescue mail of the server
        :param pulumi.Input[builtins.str] rescue_ssh_key: Public SSH Key used in the rescue mode
        :param pulumi.Input[builtins.str] reverse: Dedicated server reverse
        :param pulumi.Input[builtins.str] root_device: Root device of the server
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] run_actions_before_destroys: Actions to run before destroying the resource
        :param pulumi.Input[builtins.float] server_id: Server id
        :param pulumi.Input[builtins.str] service_name: The service_name of your dedicated server
        :param pulumi.Input[builtins.str] state: All states a Dedicated can be in (error, hacked, hackedBlocked, ok)
        :param pulumi.Input[Sequence[pulumi.Input[Union['ServerStorageArgs', 'ServerStorageArgsDict']]]] storages: OS reinstallation storage configurations
        :param pulumi.Input[builtins.str] support_level: Dedicated server support level (critical, fastpath, gs, pro)
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ServerState.__new__(_ServerState)

        __props__.__dict__["availability_zone"] = availability_zone
        __props__.__dict__["boot_id"] = boot_id
        __props__.__dict__["boot_script"] = boot_script
        __props__.__dict__["commercial_range"] = commercial_range
        __props__.__dict__["customizations"] = customizations
        __props__.__dict__["datacenter"] = datacenter
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["efi_bootloader_path"] = efi_bootloader_path
        __props__.__dict__["iam"] = iam
        __props__.__dict__["ip"] = ip
        __props__.__dict__["keep_service_after_destroy"] = keep_service_after_destroy
        __props__.__dict__["link_speed"] = link_speed
        __props__.__dict__["monitoring"] = monitoring
        __props__.__dict__["name"] = name
        __props__.__dict__["new_upgrade_system"] = new_upgrade_system
        __props__.__dict__["no_intervention"] = no_intervention
        __props__.__dict__["order"] = order
        __props__.__dict__["os"] = os
        __props__.__dict__["ovh_subsidiary"] = ovh_subsidiary
        __props__.__dict__["plan_options"] = plan_options
        __props__.__dict__["plans"] = plans
        __props__.__dict__["power_state"] = power_state
        __props__.__dict__["prevent_install_on_create"] = prevent_install_on_create
        __props__.__dict__["prevent_install_on_import"] = prevent_install_on_import
        __props__.__dict__["professional_use"] = professional_use
        __props__.__dict__["properties"] = properties
        __props__.__dict__["rack"] = rack
        __props__.__dict__["region"] = region
        __props__.__dict__["rescue_mail"] = rescue_mail
        __props__.__dict__["rescue_ssh_key"] = rescue_ssh_key
        __props__.__dict__["reverse"] = reverse
        __props__.__dict__["root_device"] = root_device
        __props__.__dict__["run_actions_before_destroys"] = run_actions_before_destroys
        __props__.__dict__["server_id"] = server_id
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["state"] = state
        __props__.__dict__["storages"] = storages
        __props__.__dict__["support_level"] = support_level
        return Server(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="availabilityZone")
    def availability_zone(self) -> pulumi.Output[builtins.str]:
        """
        Dedicated AZ localisation
        """
        return pulumi.get(self, "availability_zone")

    @property
    @pulumi.getter(name="bootId")
    def boot_id(self) -> pulumi.Output[builtins.float]:
        """
        Boot id of the server
        """
        return pulumi.get(self, "boot_id")

    @property
    @pulumi.getter(name="bootScript")
    def boot_script(self) -> pulumi.Output[builtins.str]:
        """
        Boot script of the server
        """
        return pulumi.get(self, "boot_script")

    @property
    @pulumi.getter(name="commercialRange")
    def commercial_range(self) -> pulumi.Output[builtins.str]:
        """
        Dedicated server commercial range
        """
        return pulumi.get(self, "commercial_range")

    @property
    @pulumi.getter
    def customizations(self) -> pulumi.Output[Optional['outputs.ServerCustomizations']]:
        """
        OS reinstallation customizations
        """
        return pulumi.get(self, "customizations")

    @property
    @pulumi.getter
    def datacenter(self) -> pulumi.Output[builtins.str]:
        """
        Dedicated datacenter localisation (bhs1,bhs2,...)
        """
        return pulumi.get(self, "datacenter")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Resource display name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="efiBootloaderPath")
    def efi_bootloader_path(self) -> pulumi.Output[builtins.str]:
        """
        Path of the EFI bootloader
        """
        return pulumi.get(self, "efi_bootloader_path")

    @property
    @pulumi.getter
    def iam(self) -> pulumi.Output['outputs.ServerIam']:
        """
        IAM resource information
        """
        return pulumi.get(self, "iam")

    @property
    @pulumi.getter
    def ip(self) -> pulumi.Output[builtins.str]:
        """
        Dedicated server ip (IPv4)
        """
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter(name="keepServiceAfterDestroy")
    def keep_service_after_destroy(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Whether we should avoid terminating the service when destroying the resource
        """
        return pulumi.get(self, "keep_service_after_destroy")

    @property
    @pulumi.getter(name="linkSpeed")
    def link_speed(self) -> pulumi.Output[builtins.float]:
        """
        Link speed of the server
        """
        return pulumi.get(self, "link_speed")

    @property
    @pulumi.getter
    def monitoring(self) -> pulumi.Output[builtins.bool]:
        """
        Icmp monitoring state
        """
        return pulumi.get(self, "monitoring")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        Dedicated server name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="newUpgradeSystem")
    def new_upgrade_system(self) -> pulumi.Output[builtins.bool]:
        return pulumi.get(self, "new_upgrade_system")

    @property
    @pulumi.getter(name="noIntervention")
    def no_intervention(self) -> pulumi.Output[builtins.bool]:
        """
        Prevent datacenter intervention
        """
        return pulumi.get(self, "no_intervention")

    @property
    @pulumi.getter
    def order(self) -> pulumi.Output['outputs.ServerOrder']:
        """
        Details about an Order
        """
        return pulumi.get(self, "order")

    @property
    @pulumi.getter
    def os(self) -> pulumi.Output[builtins.str]:
        """
        Operating system
        """
        return pulumi.get(self, "os")

    @property
    @pulumi.getter(name="ovhSubsidiary")
    def ovh_subsidiary(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        OVH subsidiaries
        """
        return pulumi.get(self, "ovh_subsidiary")

    @property
    @pulumi.getter(name="planOptions")
    def plan_options(self) -> pulumi.Output[Optional[Sequence['outputs.ServerPlanOption']]]:
        return pulumi.get(self, "plan_options")

    @property
    @pulumi.getter
    def plans(self) -> pulumi.Output[Optional[Sequence['outputs.ServerPlan']]]:
        return pulumi.get(self, "plans")

    @property
    @pulumi.getter(name="powerState")
    def power_state(self) -> pulumi.Output[builtins.str]:
        """
        Power state of the server (poweron, poweroff)
        """
        return pulumi.get(self, "power_state")

    @property
    @pulumi.getter(name="preventInstallOnCreate")
    def prevent_install_on_create(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Defines whether the server should not be reinstalled after creating the resource
        """
        return pulumi.get(self, "prevent_install_on_create")

    @property
    @pulumi.getter(name="preventInstallOnImport")
    def prevent_install_on_import(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Defines whether the server should not be reinstalled when importing the resource
        """
        return pulumi.get(self, "prevent_install_on_import")

    @property
    @pulumi.getter(name="professionalUse")
    def professional_use(self) -> pulumi.Output[builtins.bool]:
        """
        Does this server have professional use option
        """
        return pulumi.get(self, "professional_use")

    @property
    @pulumi.getter
    def properties(self) -> pulumi.Output[Optional[Mapping[str, builtins.str]]]:
        """
        Arbitrary properties to pass to cloud-init's config drive datasource
        """
        return pulumi.get(self, "properties")

    @property
    @pulumi.getter
    def rack(self) -> pulumi.Output[builtins.str]:
        """
        Rack id of the server
        """
        return pulumi.get(self, "rack")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[builtins.str]:
        """
        Dedicated region localisation
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="rescueMail")
    def rescue_mail(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Rescue mail of the server
        """
        return pulumi.get(self, "rescue_mail")

    @property
    @pulumi.getter(name="rescueSshKey")
    def rescue_ssh_key(self) -> pulumi.Output[Optional[builtins.str]]:
        """
        Public SSH Key used in the rescue mode
        """
        return pulumi.get(self, "rescue_ssh_key")

    @property
    @pulumi.getter
    def reverse(self) -> pulumi.Output[builtins.str]:
        """
        Dedicated server reverse
        """
        return pulumi.get(self, "reverse")

    @property
    @pulumi.getter(name="rootDevice")
    def root_device(self) -> pulumi.Output[builtins.str]:
        """
        Root device of the server
        """
        return pulumi.get(self, "root_device")

    @property
    @pulumi.getter(name="runActionsBeforeDestroys")
    def run_actions_before_destroys(self) -> pulumi.Output[Optional[Sequence[builtins.str]]]:
        """
        Actions to run before destroying the resource
        """
        return pulumi.get(self, "run_actions_before_destroys")

    @property
    @pulumi.getter(name="serverId")
    def server_id(self) -> pulumi.Output[builtins.float]:
        """
        Server id
        """
        return pulumi.get(self, "server_id")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The service_name of your dedicated server
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[builtins.str]:
        """
        All states a Dedicated can be in (error, hacked, hackedBlocked, ok)
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter
    def storages(self) -> pulumi.Output[Optional[Sequence['outputs.ServerStorage']]]:
        """
        OS reinstallation storage configurations
        """
        return pulumi.get(self, "storages")

    @property
    @pulumi.getter(name="supportLevel")
    def support_level(self) -> pulumi.Output[builtins.str]:
        """
        Dedicated server support level (critical, fastpath, gs, pro)
        """
        return pulumi.get(self, "support_level")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetPrivateDatabaseAllowlistResult',
    'AwaitableGetPrivateDatabaseAllowlistResult',
    'get_private_database_allowlist',
    'get_private_database_allowlist_output',
]

@pulumi.output_type
class GetPrivateDatabaseAllowlistResult:
    """
    A collection of values returned by getPrivateDatabaseAllowlist.
    """
    def __init__(__self__, creation_date=None, id=None, ip=None, last_update=None, name=None, service=None, service_name=None, sftp=None, status=None):
        if creation_date and not isinstance(creation_date, str):
            raise TypeError("Expected argument 'creation_date' to be a str")
        pulumi.set(__self__, "creation_date", creation_date)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ip and not isinstance(ip, str):
            raise TypeError("Expected argument 'ip' to be a str")
        pulumi.set(__self__, "ip", ip)
        if last_update and not isinstance(last_update, str):
            raise TypeError("Expected argument 'last_update' to be a str")
        pulumi.set(__self__, "last_update", last_update)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if service and not isinstance(service, bool):
            raise TypeError("Expected argument 'service' to be a bool")
        pulumi.set(__self__, "service", service)
        if service_name and not isinstance(service_name, str):
            raise TypeError("Expected argument 'service_name' to be a str")
        pulumi.set(__self__, "service_name", service_name)
        if sftp and not isinstance(sftp, bool):
            raise TypeError("Expected argument 'sftp' to be a bool")
        pulumi.set(__self__, "sftp", sftp)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="creationDate")
    def creation_date(self) -> builtins.str:
        """
        Creation date of the database
        """
        return pulumi.get(self, "creation_date")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ip(self) -> Optional[builtins.str]:
        return pulumi.get(self, "ip")

    @property
    @pulumi.getter(name="lastUpdate")
    def last_update(self) -> builtins.str:
        """
        The last update date of this whitelist
        """
        return pulumi.get(self, "last_update")

    @property
    @pulumi.getter
    def name(self) -> builtins.str:
        """
        Custom name for your Whitelisted IP
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def service(self) -> builtins.bool:
        """
        Authorize this IP to access service port
        """
        return pulumi.get(self, "service")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> builtins.str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def sftp(self) -> builtins.bool:
        """
        Authorize this IP to access SFTP port
        """
        return pulumi.get(self, "sftp")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        Whitelist status
        """
        return pulumi.get(self, "status")


class AwaitableGetPrivateDatabaseAllowlistResult(GetPrivateDatabaseAllowlistResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetPrivateDatabaseAllowlistResult(
            creation_date=self.creation_date,
            id=self.id,
            ip=self.ip,
            last_update=self.last_update,
            name=self.name,
            service=self.service,
            service_name=self.service_name,
            sftp=self.sftp,
            status=self.status)


def get_private_database_allowlist(ip: Optional[builtins.str] = None,
                                   service_name: Optional[builtins.str] = None,
                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetPrivateDatabaseAllowlistResult:
    """
    Use this data source to retrieve information about an hosting privatedatabase whitelist.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    whitelist = ovh.Hosting.get_private_database_allowlist(service_name="XXXXXX",
        ip="XXXXXX")
    ```


    :param builtins.str ip: The whitelisted IP in your instance
    :param builtins.str service_name: The internal name of your private database
    """
    __args__ = dict()
    __args__['ip'] = ip
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('ovh:Hosting/getPrivateDatabaseAllowlist:getPrivateDatabaseAllowlist', __args__, opts=opts, typ=GetPrivateDatabaseAllowlistResult).value

    return AwaitableGetPrivateDatabaseAllowlistResult(
        creation_date=pulumi.get(__ret__, 'creation_date'),
        id=pulumi.get(__ret__, 'id'),
        ip=pulumi.get(__ret__, 'ip'),
        last_update=pulumi.get(__ret__, 'last_update'),
        name=pulumi.get(__ret__, 'name'),
        service=pulumi.get(__ret__, 'service'),
        service_name=pulumi.get(__ret__, 'service_name'),
        sftp=pulumi.get(__ret__, 'sftp'),
        status=pulumi.get(__ret__, 'status'))
def get_private_database_allowlist_output(ip: Optional[pulumi.Input[Optional[builtins.str]]] = None,
                                          service_name: Optional[pulumi.Input[builtins.str]] = None,
                                          opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetPrivateDatabaseAllowlistResult]:
    """
    Use this data source to retrieve information about an hosting privatedatabase whitelist.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_ovh as ovh

    whitelist = ovh.Hosting.get_private_database_allowlist(service_name="XXXXXX",
        ip="XXXXXX")
    ```


    :param builtins.str ip: The whitelisted IP in your instance
    :param builtins.str service_name: The internal name of your private database
    """
    __args__ = dict()
    __args__['ip'] = ip
    __args__['serviceName'] = service_name
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('ovh:Hosting/getPrivateDatabaseAllowlist:getPrivateDatabaseAllowlist', __args__, opts=opts, typ=GetPrivateDatabaseAllowlistResult)
    return __ret__.apply(lambda __response__: GetPrivateDatabaseAllowlistResult(
        creation_date=pulumi.get(__response__, 'creation_date'),
        id=pulumi.get(__response__, 'id'),
        ip=pulumi.get(__response__, 'ip'),
        last_update=pulumi.get(__response__, 'last_update'),
        name=pulumi.get(__response__, 'name'),
        service=pulumi.get(__response__, 'service'),
        service_name=pulumi.get(__response__, 'service_name'),
        sftp=pulumi.get(__response__, 'sftp'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NetworkPrivateSubnetArgs', 'NetworkPrivateSubnet']

@pulumi.input_type
class NetworkPrivateSubnetArgs:
    def __init__(__self__, *,
                 end: pulumi.Input[builtins.str],
                 network: pulumi.Input[builtins.str],
                 network_id: pulumi.Input[builtins.str],
                 region: pulumi.Input[builtins.str],
                 start: pulumi.Input[builtins.str],
                 dhcp: Optional[pulumi.Input[builtins.bool]] = None,
                 no_gateway: Optional[pulumi.Input[builtins.bool]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a NetworkPrivateSubnet resource.
        :param pulumi.Input[builtins.str] end: Last ip for this region. Changing this value recreates the subnet.
        :param pulumi.Input[builtins.str] network: Global network in CIDR format. Changing this value recreates the subnet
        :param pulumi.Input[builtins.str] network_id: The id of the network. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.str] region: The region in which the network subnet will be created. Ex.: "GRA1". Changing this value recreates the resource.
        :param pulumi.Input[builtins.str] start: First ip for this region. Changing this value recreates the subnet.
        :param pulumi.Input[builtins.bool] dhcp: Enable DHCP. Changing this forces a new resource to be created. Defaults to false.
        :param pulumi.Input[builtins.bool] no_gateway: Set to true if you don't want to set a default gateway IP. Changing this value recreates the resource. Defaults to false.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        pulumi.set(__self__, "end", end)
        pulumi.set(__self__, "network", network)
        pulumi.set(__self__, "network_id", network_id)
        pulumi.set(__self__, "region", region)
        pulumi.set(__self__, "start", start)
        if dhcp is not None:
            pulumi.set(__self__, "dhcp", dhcp)
        if no_gateway is not None:
            pulumi.set(__self__, "no_gateway", no_gateway)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter
    def end(self) -> pulumi.Input[builtins.str]:
        """
        Last ip for this region. Changing this value recreates the subnet.
        """
        return pulumi.get(self, "end")

    @end.setter
    def end(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "end", value)

    @property
    @pulumi.getter
    def network(self) -> pulumi.Input[builtins.str]:
        """
        Global network in CIDR format. Changing this value recreates the subnet
        """
        return pulumi.get(self, "network")

    @network.setter
    def network(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "network", value)

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> pulumi.Input[builtins.str]:
        """
        The id of the network. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "network_id")

    @network_id.setter
    def network_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "network_id", value)

    @property
    @pulumi.getter
    def region(self) -> pulumi.Input[builtins.str]:
        """
        The region in which the network subnet will be created. Ex.: "GRA1". Changing this value recreates the resource.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter
    def start(self) -> pulumi.Input[builtins.str]:
        """
        First ip for this region. Changing this value recreates the subnet.
        """
        return pulumi.get(self, "start")

    @start.setter
    def start(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "start", value)

    @property
    @pulumi.getter
    def dhcp(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable DHCP. Changing this forces a new resource to be created. Defaults to false.
        """
        return pulumi.get(self, "dhcp")

    @dhcp.setter
    def dhcp(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "dhcp", value)

    @property
    @pulumi.getter(name="noGateway")
    def no_gateway(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set to true if you don't want to set a default gateway IP. Changing this value recreates the resource. Defaults to false.
        """
        return pulumi.get(self, "no_gateway")

    @no_gateway.setter
    def no_gateway(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "no_gateway", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)


@pulumi.input_type
class _NetworkPrivateSubnetState:
    def __init__(__self__, *,
                 cidr: Optional[pulumi.Input[builtins.str]] = None,
                 dhcp: Optional[pulumi.Input[builtins.bool]] = None,
                 end: Optional[pulumi.Input[builtins.str]] = None,
                 gateway_ip: Optional[pulumi.Input[builtins.str]] = None,
                 ip_pools: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkPrivateSubnetIpPoolArgs']]]] = None,
                 network: Optional[pulumi.Input[builtins.str]] = None,
                 network_id: Optional[pulumi.Input[builtins.str]] = None,
                 no_gateway: Optional[pulumi.Input[builtins.bool]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 start: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering NetworkPrivateSubnet resources.
        :param pulumi.Input[builtins.str] cidr: Ip Block representing the subnet cidr.
        :param pulumi.Input[builtins.bool] dhcp: Enable DHCP. Changing this forces a new resource to be created. Defaults to false.
        :param pulumi.Input[builtins.str] end: Last ip for this region. Changing this value recreates the subnet.
        :param pulumi.Input[builtins.str] gateway_ip: The IP of the gateway
        :param pulumi.Input[Sequence[pulumi.Input['NetworkPrivateSubnetIpPoolArgs']]] ip_pools: List of ip pools allocated in the subnet.
               * `ip_pools/network` - Global network with cidr.
               * `ip_pools/region` - Region where this subnet is created.
               * `ip_pools/dhcp` - DHCP enabled.
               * `ip_pools/end` - Last ip for this region.
               * `ip_pools/start` - First ip for this region.
        :param pulumi.Input[builtins.str] network: Global network in CIDR format. Changing this value recreates the subnet
        :param pulumi.Input[builtins.str] network_id: The id of the network. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.bool] no_gateway: Set to true if you don't want to set a default gateway IP. Changing this value recreates the resource. Defaults to false.
        :param pulumi.Input[builtins.str] region: The region in which the network subnet will be created. Ex.: "GRA1". Changing this value recreates the resource.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] start: First ip for this region. Changing this value recreates the subnet.
        """
        if cidr is not None:
            pulumi.set(__self__, "cidr", cidr)
        if dhcp is not None:
            pulumi.set(__self__, "dhcp", dhcp)
        if end is not None:
            pulumi.set(__self__, "end", end)
        if gateway_ip is not None:
            pulumi.set(__self__, "gateway_ip", gateway_ip)
        if ip_pools is not None:
            pulumi.set(__self__, "ip_pools", ip_pools)
        if network is not None:
            pulumi.set(__self__, "network", network)
        if network_id is not None:
            pulumi.set(__self__, "network_id", network_id)
        if no_gateway is not None:
            pulumi.set(__self__, "no_gateway", no_gateway)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if service_name is not None:
            pulumi.set(__self__, "service_name", service_name)
        if start is not None:
            pulumi.set(__self__, "start", start)

    @property
    @pulumi.getter
    def cidr(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Ip Block representing the subnet cidr.
        """
        return pulumi.get(self, "cidr")

    @cidr.setter
    def cidr(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cidr", value)

    @property
    @pulumi.getter
    def dhcp(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Enable DHCP. Changing this forces a new resource to be created. Defaults to false.
        """
        return pulumi.get(self, "dhcp")

    @dhcp.setter
    def dhcp(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "dhcp", value)

    @property
    @pulumi.getter
    def end(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Last ip for this region. Changing this value recreates the subnet.
        """
        return pulumi.get(self, "end")

    @end.setter
    def end(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "end", value)

    @property
    @pulumi.getter(name="gatewayIp")
    def gateway_ip(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The IP of the gateway
        """
        return pulumi.get(self, "gateway_ip")

    @gateway_ip.setter
    def gateway_ip(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "gateway_ip", value)

    @property
    @pulumi.getter(name="ipPools")
    def ip_pools(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['NetworkPrivateSubnetIpPoolArgs']]]]:
        """
        List of ip pools allocated in the subnet.
        * `ip_pools/network` - Global network with cidr.
        * `ip_pools/region` - Region where this subnet is created.
        * `ip_pools/dhcp` - DHCP enabled.
        * `ip_pools/end` - Last ip for this region.
        * `ip_pools/start` - First ip for this region.
        """
        return pulumi.get(self, "ip_pools")

    @ip_pools.setter
    def ip_pools(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['NetworkPrivateSubnetIpPoolArgs']]]]):
        pulumi.set(self, "ip_pools", value)

    @property
    @pulumi.getter
    def network(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        Global network in CIDR format. Changing this value recreates the subnet
        """
        return pulumi.get(self, "network")

    @network.setter
    def network(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network", value)

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the network. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "network_id")

    @network_id.setter
    def network_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "network_id", value)

    @property
    @pulumi.getter(name="noGateway")
    def no_gateway(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        Set to true if you don't want to set a default gateway IP. Changing this value recreates the resource. Defaults to false.
        """
        return pulumi.get(self, "no_gateway")

    @no_gateway.setter
    def no_gateway(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "no_gateway", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The region in which the network subnet will be created. Ex.: "GRA1". Changing this value recreates the resource.
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @service_name.setter
    def service_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "service_name", value)

    @property
    @pulumi.getter
    def start(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        First ip for this region. Changing this value recreates the subnet.
        """
        return pulumi.get(self, "start")

    @start.setter
    def start(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "start", value)


@pulumi.type_token("ovh:CloudProject/networkPrivateSubnet:NetworkPrivateSubnet")
class NetworkPrivateSubnet(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dhcp: Optional[pulumi.Input[builtins.bool]] = None,
                 end: Optional[pulumi.Input[builtins.str]] = None,
                 network: Optional[pulumi.Input[builtins.str]] = None,
                 network_id: Optional[pulumi.Input[builtins.str]] = None,
                 no_gateway: Optional[pulumi.Input[builtins.bool]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 start: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        Creates a subnet in a private network of a public cloud project.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        subnet = ovh.cloud_project.NetworkPrivateSubnet("subnet",
            service_name="xxxxx",
            network_id="0234543",
            region="GRA1",
            start="192.168.168.100",
            end="192.168.168.200",
            network="192.168.168.0/24",
            dhcp=True,
            no_gateway=False)
        ```

        ## Import

        Subnet in a private network of a public cloud project can be imported using the `service_name` , the `network_id` as `pn-xxxx` format and the `subnet_id`, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProject/networkPrivateSubnet:NetworkPrivateSubnet mysubnet service_name/network_id/subnet_id
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] dhcp: Enable DHCP. Changing this forces a new resource to be created. Defaults to false.
        :param pulumi.Input[builtins.str] end: Last ip for this region. Changing this value recreates the subnet.
        :param pulumi.Input[builtins.str] network: Global network in CIDR format. Changing this value recreates the subnet
        :param pulumi.Input[builtins.str] network_id: The id of the network. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.bool] no_gateway: Set to true if you don't want to set a default gateway IP. Changing this value recreates the resource. Defaults to false.
        :param pulumi.Input[builtins.str] region: The region in which the network subnet will be created. Ex.: "GRA1". Changing this value recreates the resource.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] start: First ip for this region. Changing this value recreates the subnet.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NetworkPrivateSubnetArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Creates a subnet in a private network of a public cloud project.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_ovh as ovh

        subnet = ovh.cloud_project.NetworkPrivateSubnet("subnet",
            service_name="xxxxx",
            network_id="0234543",
            region="GRA1",
            start="192.168.168.100",
            end="192.168.168.200",
            network="192.168.168.0/24",
            dhcp=True,
            no_gateway=False)
        ```

        ## Import

        Subnet in a private network of a public cloud project can be imported using the `service_name` , the `network_id` as `pn-xxxx` format and the `subnet_id`, separated by "/" E.g.,

        bash

        ```sh
        $ pulumi import ovh:CloudProject/networkPrivateSubnet:NetworkPrivateSubnet mysubnet service_name/network_id/subnet_id
        ```

        :param str resource_name: The name of the resource.
        :param NetworkPrivateSubnetArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NetworkPrivateSubnetArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 dhcp: Optional[pulumi.Input[builtins.bool]] = None,
                 end: Optional[pulumi.Input[builtins.str]] = None,
                 network: Optional[pulumi.Input[builtins.str]] = None,
                 network_id: Optional[pulumi.Input[builtins.str]] = None,
                 no_gateway: Optional[pulumi.Input[builtins.bool]] = None,
                 region: Optional[pulumi.Input[builtins.str]] = None,
                 service_name: Optional[pulumi.Input[builtins.str]] = None,
                 start: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NetworkPrivateSubnetArgs.__new__(NetworkPrivateSubnetArgs)

            __props__.__dict__["dhcp"] = dhcp
            if end is None and not opts.urn:
                raise TypeError("Missing required property 'end'")
            __props__.__dict__["end"] = end
            if network is None and not opts.urn:
                raise TypeError("Missing required property 'network'")
            __props__.__dict__["network"] = network
            if network_id is None and not opts.urn:
                raise TypeError("Missing required property 'network_id'")
            __props__.__dict__["network_id"] = network_id
            __props__.__dict__["no_gateway"] = no_gateway
            if region is None and not opts.urn:
                raise TypeError("Missing required property 'region'")
            __props__.__dict__["region"] = region
            __props__.__dict__["service_name"] = service_name
            if start is None and not opts.urn:
                raise TypeError("Missing required property 'start'")
            __props__.__dict__["start"] = start
            __props__.__dict__["cidr"] = None
            __props__.__dict__["gateway_ip"] = None
            __props__.__dict__["ip_pools"] = None
        super(NetworkPrivateSubnet, __self__).__init__(
            'ovh:CloudProject/networkPrivateSubnet:NetworkPrivateSubnet',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            cidr: Optional[pulumi.Input[builtins.str]] = None,
            dhcp: Optional[pulumi.Input[builtins.bool]] = None,
            end: Optional[pulumi.Input[builtins.str]] = None,
            gateway_ip: Optional[pulumi.Input[builtins.str]] = None,
            ip_pools: Optional[pulumi.Input[Sequence[pulumi.Input[Union['NetworkPrivateSubnetIpPoolArgs', 'NetworkPrivateSubnetIpPoolArgsDict']]]]] = None,
            network: Optional[pulumi.Input[builtins.str]] = None,
            network_id: Optional[pulumi.Input[builtins.str]] = None,
            no_gateway: Optional[pulumi.Input[builtins.bool]] = None,
            region: Optional[pulumi.Input[builtins.str]] = None,
            service_name: Optional[pulumi.Input[builtins.str]] = None,
            start: Optional[pulumi.Input[builtins.str]] = None) -> 'NetworkPrivateSubnet':
        """
        Get an existing NetworkPrivateSubnet resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] cidr: Ip Block representing the subnet cidr.
        :param pulumi.Input[builtins.bool] dhcp: Enable DHCP. Changing this forces a new resource to be created. Defaults to false.
        :param pulumi.Input[builtins.str] end: Last ip for this region. Changing this value recreates the subnet.
        :param pulumi.Input[builtins.str] gateway_ip: The IP of the gateway
        :param pulumi.Input[Sequence[pulumi.Input[Union['NetworkPrivateSubnetIpPoolArgs', 'NetworkPrivateSubnetIpPoolArgsDict']]]] ip_pools: List of ip pools allocated in the subnet.
               * `ip_pools/network` - Global network with cidr.
               * `ip_pools/region` - Region where this subnet is created.
               * `ip_pools/dhcp` - DHCP enabled.
               * `ip_pools/end` - Last ip for this region.
               * `ip_pools/start` - First ip for this region.
        :param pulumi.Input[builtins.str] network: Global network in CIDR format. Changing this value recreates the subnet
        :param pulumi.Input[builtins.str] network_id: The id of the network. Changing this forces a new resource to be created.
        :param pulumi.Input[builtins.bool] no_gateway: Set to true if you don't want to set a default gateway IP. Changing this value recreates the resource. Defaults to false.
        :param pulumi.Input[builtins.str] region: The region in which the network subnet will be created. Ex.: "GRA1". Changing this value recreates the resource.
        :param pulumi.Input[builtins.str] service_name: The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        :param pulumi.Input[builtins.str] start: First ip for this region. Changing this value recreates the subnet.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NetworkPrivateSubnetState.__new__(_NetworkPrivateSubnetState)

        __props__.__dict__["cidr"] = cidr
        __props__.__dict__["dhcp"] = dhcp
        __props__.__dict__["end"] = end
        __props__.__dict__["gateway_ip"] = gateway_ip
        __props__.__dict__["ip_pools"] = ip_pools
        __props__.__dict__["network"] = network
        __props__.__dict__["network_id"] = network_id
        __props__.__dict__["no_gateway"] = no_gateway
        __props__.__dict__["region"] = region
        __props__.__dict__["service_name"] = service_name
        __props__.__dict__["start"] = start
        return NetworkPrivateSubnet(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def cidr(self) -> pulumi.Output[builtins.str]:
        """
        Ip Block representing the subnet cidr.
        """
        return pulumi.get(self, "cidr")

    @property
    @pulumi.getter
    def dhcp(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Enable DHCP. Changing this forces a new resource to be created. Defaults to false.
        """
        return pulumi.get(self, "dhcp")

    @property
    @pulumi.getter
    def end(self) -> pulumi.Output[builtins.str]:
        """
        Last ip for this region. Changing this value recreates the subnet.
        """
        return pulumi.get(self, "end")

    @property
    @pulumi.getter(name="gatewayIp")
    def gateway_ip(self) -> pulumi.Output[builtins.str]:
        """
        The IP of the gateway
        """
        return pulumi.get(self, "gateway_ip")

    @property
    @pulumi.getter(name="ipPools")
    def ip_pools(self) -> pulumi.Output[Sequence['outputs.NetworkPrivateSubnetIpPool']]:
        """
        List of ip pools allocated in the subnet.
        * `ip_pools/network` - Global network with cidr.
        * `ip_pools/region` - Region where this subnet is created.
        * `ip_pools/dhcp` - DHCP enabled.
        * `ip_pools/end` - Last ip for this region.
        * `ip_pools/start` - First ip for this region.
        """
        return pulumi.get(self, "ip_pools")

    @property
    @pulumi.getter
    def network(self) -> pulumi.Output[builtins.str]:
        """
        Global network in CIDR format. Changing this value recreates the subnet
        """
        return pulumi.get(self, "network")

    @property
    @pulumi.getter(name="networkId")
    def network_id(self) -> pulumi.Output[builtins.str]:
        """
        The id of the network. Changing this forces a new resource to be created.
        """
        return pulumi.get(self, "network_id")

    @property
    @pulumi.getter(name="noGateway")
    def no_gateway(self) -> pulumi.Output[Optional[builtins.bool]]:
        """
        Set to true if you don't want to set a default gateway IP. Changing this value recreates the resource. Defaults to false.
        """
        return pulumi.get(self, "no_gateway")

    @property
    @pulumi.getter
    def region(self) -> pulumi.Output[builtins.str]:
        """
        The region in which the network subnet will be created. Ex.: "GRA1". Changing this value recreates the resource.
        """
        return pulumi.get(self, "region")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> pulumi.Output[builtins.str]:
        """
        The id of the public cloud project. If omitted, the `OVH_CLOUD_PROJECT_SERVICE` environment variable is used.
        """
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def start(self) -> pulumi.Output[builtins.str]:
        """
        First ip for this region. Changing this value recreates the subnet.
        """
        return pulumi.get(self, "start")




# coding=utf-8
# *** WARNING: this file was generated by pulumi-language-python. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'OkmsIam',
    'ServiceKeyJWKIam',
    'ServiceKeyJWKKey',
    'GetOkmsResourceIamResult',
    'GetOkmsServiceKeyIamResult',
    'GetOkmsServiceKeyJwkIamResult',
    'GetOkmsServiceKeyJwkKeyResult',
    'GetOkmsServiceKeyPemIamResult',
    'GetOkmsServiceKeyPemKeysPemResult',
]

@pulumi.output_type
class OkmsIam(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "displayName":
            suggest = "display_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in OkmsIam. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        OkmsIam.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        OkmsIam.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 display_name: Optional[builtins.str] = None,
                 id: Optional[builtins.str] = None,
                 tags: Optional[Mapping[str, builtins.str]] = None,
                 urn: Optional[builtins.str] = None):
        """
        :param builtins.str display_name: (String) Resource display name
        :param builtins.str id: (String) Unique identifier of the resource
        :param Mapping[str, builtins.str] tags: (Map of String) Resource tags. Tags that were internally computed are prefixed with ovh:
        :param builtins.str urn: (String) Unique resource name used in policies
        """
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if urn is not None:
            pulumi.set(__self__, "urn", urn)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[builtins.str]:
        """
        (String) Resource display name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> Optional[builtins.str]:
        """
        (String) Unique identifier of the resource
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, builtins.str]]:
        """
        (Map of String) Resource tags. Tags that were internally computed are prefixed with ovh:
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def urn(self) -> Optional[builtins.str]:
        """
        (String) Unique resource name used in policies
        """
        return pulumi.get(self, "urn")


@pulumi.output_type
class ServiceKeyJWKIam(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "displayName":
            suggest = "display_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ServiceKeyJWKIam. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ServiceKeyJWKIam.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ServiceKeyJWKIam.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 display_name: Optional[builtins.str] = None,
                 id: Optional[builtins.str] = None,
                 tags: Optional[Mapping[str, builtins.str]] = None,
                 urn: Optional[builtins.str] = None):
        """
        :param builtins.str display_name: Resource display name
        :param builtins.str id: Unique identifier of the resource
        :param Mapping[str, builtins.str] tags: Resource tags. Tags that were internally computed are prefixed with ovh:
        :param builtins.str urn: Unique resource name used in policies
        """
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if urn is not None:
            pulumi.set(__self__, "urn", urn)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[builtins.str]:
        """
        Resource display name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> Optional[builtins.str]:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, builtins.str]]:
        """
        Resource tags. Tags that were internally computed are prefixed with ovh:
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def urn(self) -> Optional[builtins.str]:
        """
        Unique resource name used in policies
        """
        return pulumi.get(self, "urn")


@pulumi.output_type
class ServiceKeyJWKKey(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "keyOps":
            suggest = "key_ops"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ServiceKeyJWKKey. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ServiceKeyJWKKey.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ServiceKeyJWKKey.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 key_ops: Sequence[builtins.str],
                 kty: builtins.str,
                 alg: Optional[builtins.str] = None,
                 crv: Optional[builtins.str] = None,
                 d: Optional[builtins.str] = None,
                 dp: Optional[builtins.str] = None,
                 dq: Optional[builtins.str] = None,
                 e: Optional[builtins.str] = None,
                 k: Optional[builtins.str] = None,
                 kid: Optional[builtins.str] = None,
                 n: Optional[builtins.str] = None,
                 p: Optional[builtins.str] = None,
                 q: Optional[builtins.str] = None,
                 qi: Optional[builtins.str] = None,
                 use: Optional[builtins.str] = None,
                 x: Optional[builtins.str] = None,
                 y: Optional[builtins.str] = None):
        """
        :param Sequence[builtins.str] key_ops: The operation for which the key is intended to be used
        :param builtins.str kty: Key type parameter identifies the cryptographic algorithm family used with the key, such as RSA or EC
        :param builtins.str alg: The algorithm intended to be used with the key
        :param builtins.str crv: The cryptographic curve used with the key
        :param builtins.str d: The RSA or EC private exponent
        :param builtins.str dp: The RSA private key's first factor CRT exponent
        :param builtins.str dq: The RSA private key's second factor CRT exponent
        :param builtins.str e: The exponent value for the RSA public key
        :param builtins.str k: The value of the symmetric (or other single-valued) key
        :param builtins.str kid: key ID parameter used to match a specific key
        :param builtins.str n: The modulus value for the RSA public key
        :param builtins.str p: The first prime factor of the RSA private key
        :param builtins.str q: The second prime factor of the RSA private key
        :param builtins.str qi: The CRT coefficient of the second factor of the RSA private key
        :param builtins.str use: The intended use of the public key
        :param builtins.str x: The x coordinate for the Elliptic Curve point
        :param builtins.str y: The y coordinate for the Elliptic Curve point
        """
        pulumi.set(__self__, "key_ops", key_ops)
        pulumi.set(__self__, "kty", kty)
        if alg is not None:
            pulumi.set(__self__, "alg", alg)
        if crv is not None:
            pulumi.set(__self__, "crv", crv)
        if d is not None:
            pulumi.set(__self__, "d", d)
        if dp is not None:
            pulumi.set(__self__, "dp", dp)
        if dq is not None:
            pulumi.set(__self__, "dq", dq)
        if e is not None:
            pulumi.set(__self__, "e", e)
        if k is not None:
            pulumi.set(__self__, "k", k)
        if kid is not None:
            pulumi.set(__self__, "kid", kid)
        if n is not None:
            pulumi.set(__self__, "n", n)
        if p is not None:
            pulumi.set(__self__, "p", p)
        if q is not None:
            pulumi.set(__self__, "q", q)
        if qi is not None:
            pulumi.set(__self__, "qi", qi)
        if use is not None:
            pulumi.set(__self__, "use", use)
        if x is not None:
            pulumi.set(__self__, "x", x)
        if y is not None:
            pulumi.set(__self__, "y", y)

    @property
    @pulumi.getter(name="keyOps")
    def key_ops(self) -> Sequence[builtins.str]:
        """
        The operation for which the key is intended to be used
        """
        return pulumi.get(self, "key_ops")

    @property
    @pulumi.getter
    def kty(self) -> builtins.str:
        """
        Key type parameter identifies the cryptographic algorithm family used with the key, such as RSA or EC
        """
        return pulumi.get(self, "kty")

    @property
    @pulumi.getter
    def alg(self) -> Optional[builtins.str]:
        """
        The algorithm intended to be used with the key
        """
        return pulumi.get(self, "alg")

    @property
    @pulumi.getter
    def crv(self) -> Optional[builtins.str]:
        """
        The cryptographic curve used with the key
        """
        return pulumi.get(self, "crv")

    @property
    @pulumi.getter
    def d(self) -> Optional[builtins.str]:
        """
        The RSA or EC private exponent
        """
        return pulumi.get(self, "d")

    @property
    @pulumi.getter
    def dp(self) -> Optional[builtins.str]:
        """
        The RSA private key's first factor CRT exponent
        """
        return pulumi.get(self, "dp")

    @property
    @pulumi.getter
    def dq(self) -> Optional[builtins.str]:
        """
        The RSA private key's second factor CRT exponent
        """
        return pulumi.get(self, "dq")

    @property
    @pulumi.getter
    def e(self) -> Optional[builtins.str]:
        """
        The exponent value for the RSA public key
        """
        return pulumi.get(self, "e")

    @property
    @pulumi.getter
    def k(self) -> Optional[builtins.str]:
        """
        The value of the symmetric (or other single-valued) key
        """
        return pulumi.get(self, "k")

    @property
    @pulumi.getter
    def kid(self) -> Optional[builtins.str]:
        """
        key ID parameter used to match a specific key
        """
        return pulumi.get(self, "kid")

    @property
    @pulumi.getter
    def n(self) -> Optional[builtins.str]:
        """
        The modulus value for the RSA public key
        """
        return pulumi.get(self, "n")

    @property
    @pulumi.getter
    def p(self) -> Optional[builtins.str]:
        """
        The first prime factor of the RSA private key
        """
        return pulumi.get(self, "p")

    @property
    @pulumi.getter
    def q(self) -> Optional[builtins.str]:
        """
        The second prime factor of the RSA private key
        """
        return pulumi.get(self, "q")

    @property
    @pulumi.getter
    def qi(self) -> Optional[builtins.str]:
        """
        The CRT coefficient of the second factor of the RSA private key
        """
        return pulumi.get(self, "qi")

    @property
    @pulumi.getter
    def use(self) -> Optional[builtins.str]:
        """
        The intended use of the public key
        """
        return pulumi.get(self, "use")

    @property
    @pulumi.getter
    def x(self) -> Optional[builtins.str]:
        """
        The x coordinate for the Elliptic Curve point
        """
        return pulumi.get(self, "x")

    @property
    @pulumi.getter
    def y(self) -> Optional[builtins.str]:
        """
        The y coordinate for the Elliptic Curve point
        """
        return pulumi.get(self, "y")


@pulumi.output_type
class GetOkmsResourceIamResult(dict):
    def __init__(__self__, *,
                 display_name: builtins.str,
                 id: builtins.str,
                 tags: Mapping[str, builtins.str],
                 urn: builtins.str):
        """
        :param builtins.str display_name: (String) Resource display name
        :param builtins.str id: Should be set to the ID of your KMS
        :param Mapping[str, builtins.str] tags: (Map of String) Resource tags. Tags that were internally computed are prefixed with ovh:
        :param builtins.str urn: (String) Unique resource name used in policies
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "tags", tags)
        pulumi.set(__self__, "urn", urn)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        (String) Resource display name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Should be set to the ID of your KMS
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, builtins.str]:
        """
        (Map of String) Resource tags. Tags that were internally computed are prefixed with ovh:
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def urn(self) -> builtins.str:
        """
        (String) Unique resource name used in policies
        """
        return pulumi.get(self, "urn")


@pulumi.output_type
class GetOkmsServiceKeyIamResult(dict):
    def __init__(__self__, *,
                 display_name: builtins.str,
                 id: builtins.str,
                 tags: Mapping[str, builtins.str],
                 urn: builtins.str):
        """
        :param builtins.str display_name: Resource display name
        :param builtins.str id: ID of the service key
        :param Mapping[str, builtins.str] tags: Resource tags. Tags that were internally computed are prefixed with ovh:
        :param builtins.str urn: Unique resource name used in policies
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "tags", tags)
        pulumi.set(__self__, "urn", urn)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        Resource display name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        ID of the service key
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, builtins.str]:
        """
        Resource tags. Tags that were internally computed are prefixed with ovh:
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def urn(self) -> builtins.str:
        """
        Unique resource name used in policies
        """
        return pulumi.get(self, "urn")


@pulumi.output_type
class GetOkmsServiceKeyJwkIamResult(dict):
    def __init__(__self__, *,
                 display_name: builtins.str,
                 id: builtins.str,
                 tags: Mapping[str, builtins.str],
                 urn: builtins.str):
        """
        :param builtins.str display_name: Resource display name
        :param builtins.str id: ID of the service key
        :param Mapping[str, builtins.str] tags: Resource tags. Tags that were internally computed are prefixed with ovh:
        :param builtins.str urn: Unique resource name used in policies
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "tags", tags)
        pulumi.set(__self__, "urn", urn)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        Resource display name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        ID of the service key
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, builtins.str]:
        """
        Resource tags. Tags that were internally computed are prefixed with ovh:
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def urn(self) -> builtins.str:
        """
        Unique resource name used in policies
        """
        return pulumi.get(self, "urn")


@pulumi.output_type
class GetOkmsServiceKeyJwkKeyResult(dict):
    def __init__(__self__, *,
                 alg: builtins.str,
                 crv: builtins.str,
                 e: builtins.str,
                 key_ops: Sequence[builtins.str],
                 kid: builtins.str,
                 kty: builtins.str,
                 n: builtins.str,
                 use: builtins.str,
                 x: builtins.str,
                 y: builtins.str):
        """
        :param builtins.str alg: The algorithm intended to be used with the key
        :param builtins.str crv: The cryptographic curve used with the key
        :param builtins.str e: The exponent value for the RSA public key
        :param Sequence[builtins.str] key_ops: The operation for which the key is intended to be used
        :param builtins.str kid: key ID parameter used to match a specific key
        :param builtins.str kty: Key type parameter identifies the cryptographic algorithm family used with the key, such as RSA or EC
        :param builtins.str n: The modulus value for the RSA public key
        :param builtins.str use: The intended use of the public key
        :param builtins.str x: The x coordinate for the Elliptic Curve point
        :param builtins.str y: The y coordinate for the Elliptic Curve point
        """
        pulumi.set(__self__, "alg", alg)
        pulumi.set(__self__, "crv", crv)
        pulumi.set(__self__, "e", e)
        pulumi.set(__self__, "key_ops", key_ops)
        pulumi.set(__self__, "kid", kid)
        pulumi.set(__self__, "kty", kty)
        pulumi.set(__self__, "n", n)
        pulumi.set(__self__, "use", use)
        pulumi.set(__self__, "x", x)
        pulumi.set(__self__, "y", y)

    @property
    @pulumi.getter
    def alg(self) -> builtins.str:
        """
        The algorithm intended to be used with the key
        """
        return pulumi.get(self, "alg")

    @property
    @pulumi.getter
    def crv(self) -> builtins.str:
        """
        The cryptographic curve used with the key
        """
        return pulumi.get(self, "crv")

    @property
    @pulumi.getter
    def e(self) -> builtins.str:
        """
        The exponent value for the RSA public key
        """
        return pulumi.get(self, "e")

    @property
    @pulumi.getter(name="keyOps")
    def key_ops(self) -> Sequence[builtins.str]:
        """
        The operation for which the key is intended to be used
        """
        return pulumi.get(self, "key_ops")

    @property
    @pulumi.getter
    def kid(self) -> builtins.str:
        """
        key ID parameter used to match a specific key
        """
        return pulumi.get(self, "kid")

    @property
    @pulumi.getter
    def kty(self) -> builtins.str:
        """
        Key type parameter identifies the cryptographic algorithm family used with the key, such as RSA or EC
        """
        return pulumi.get(self, "kty")

    @property
    @pulumi.getter
    def n(self) -> builtins.str:
        """
        The modulus value for the RSA public key
        """
        return pulumi.get(self, "n")

    @property
    @pulumi.getter
    def use(self) -> builtins.str:
        """
        The intended use of the public key
        """
        return pulumi.get(self, "use")

    @property
    @pulumi.getter
    def x(self) -> builtins.str:
        """
        The x coordinate for the Elliptic Curve point
        """
        return pulumi.get(self, "x")

    @property
    @pulumi.getter
    def y(self) -> builtins.str:
        """
        The y coordinate for the Elliptic Curve point
        """
        return pulumi.get(self, "y")


@pulumi.output_type
class GetOkmsServiceKeyPemIamResult(dict):
    def __init__(__self__, *,
                 display_name: builtins.str,
                 id: builtins.str,
                 tags: Mapping[str, builtins.str],
                 urn: builtins.str):
        """
        :param builtins.str display_name: Resource display name
        :param builtins.str id: Unique identifier of the resource
        :param Mapping[str, builtins.str] tags: Resource tags. Tags that were internally computed are prefixed with ovh:
        :param builtins.str urn: Unique resource name used in policies
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "tags", tags)
        pulumi.set(__self__, "urn", urn)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> builtins.str:
        """
        Resource display name
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Unique identifier of the resource
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, builtins.str]:
        """
        Resource tags. Tags that were internally computed are prefixed with ovh:
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def urn(self) -> builtins.str:
        """
        Unique resource name used in policies
        """
        return pulumi.get(self, "urn")


@pulumi.output_type
class GetOkmsServiceKeyPemKeysPemResult(dict):
    def __init__(__self__, *,
                 pem: builtins.str):
        """
        :param builtins.str pem: The key in base64 encoded PEM format
        """
        pulumi.set(__self__, "pem", pem)

    @property
    @pulumi.getter
    def pem(self) -> builtins.str:
        """
        The key in base64 encoded PEM format
        """
        return pulumi.get(self, "pem")


